/* Dbgtkint.h
 * tromey Fri Jul 15 1994
 */

#ifndef DBGTKINT_H
#define DBGTKINT_H

extern int Dbg_write _ANSI_ARGS_ ((int fd, char *string));
extern int Dbg_mark _ANSI_ARGS_ ((int fd));
extern char *Dbg_read _ANSI_ARGS_ ((int fd));
extern int Dbg_InitTk _ANSI_ARGS_ ((Tcl_Interp *interp));

#endif /* DBGTKINT_H */
